@@ -3,7 +3,6 @@ use warnings;
 use strict;
 
 BEGIN {
-	require IO::Handle;
 	require Carp;
 	require ALPM;
 }
@@ -66,8 +65,7 @@ sub _parse
 	if($err){
 		# Print the offending file and line number along with any errors...
 		# (This is why we use dies with newlines, for cascading error msgs)
-		my $lineno = $if->input_line_number();
-		die "$@$path:$lineno $line\n"
+		die "$@$path:$. $line\n"
 	}
 	return;
 }
@@ -99,7 +97,7 @@ sub _mlisthooks
 		'section' => sub {
 			my $file = shift;
 			die q{Section declaration is not allowed in Include-ed file\n($file)\n};
-	  	},
+		},
 		'field' => {
 			'Server' => sub { _addmirror($dbsref, shift, $$sectref) }
 		},
@@ -204,14 +202,11 @@ sub _parse_siglvl
 	return $opt;
 }
 
-my $ARCH;
 sub _addmirror
 {
 	my($dbs, $url, $sect) = @_;
 	die "Section has not previously been declared, cannot set URL\n" unless($sect);
 
-	# Expand $arch like pacman would do.
-	$url =~ s{\$arch(/|\$)}{$ARCH}g;
 	my $db = _getdb($dbs, $sect);
 	push @{$db->{'mirrors'}}, $url;
 	return;
@@ -229,11 +224,27 @@ sub _setopt
 	return $meth->($alpm, @val);
 }
 
+sub _setarch
+{
+	my($opts) = @_;
+	if(!$opts->{'arch'} || $opts->{'arch'} eq 'auto'){
+		chomp ($opts->{'arch'} = `uname -m`);
+	}
+}
+
+sub _expurls
+{
+	my($urls, $arch, $repo) = @_;
+	for(@$urls){
+		s/\$arch/$arch/g;
+		s/\$repo/$repo/g;
+	}
+}
 
 sub _applyopts
 {
 	my($opts, $dbs) = @_;
-	my ($root, $dbpath) = delete @{$opts}{'root', 'dbpath'};
+	my($root, $dbpath) = delete @{$opts}{'root', 'dbpath'};
 
 	unless($root){
 		$root = '/';
@@ -244,30 +255,23 @@ sub _applyopts
 	}
 
 	my $alpm = ALPM->new($root, $dbpath);
+
+	_setarch($opts);
 	while(my ($opt, $val) = each %$opts){
-		# SetOption type in typemap croaks on error for us
+		# The SetOption type in typemap croaks on error, no need to check.
 		_setopt($alpm, $opt, $val);
 	}
 
-	my $sigs = grep { /signatures/ } $alpm->caps;
+	my $usesl = grep { /signatures/ } $alpm->caps;
 	for my $db (@$dbs){
-		my $name = $db->{'name'};
-		my $mirs = $db->{'mirrors'};
-		next unless(@$mirs);
-		my $siglvl = $db->{'siglvl'};
-		if(!$sigs){
-			# Do not pass a siglvl if signatures are not supported or this
-			# will cause an ALPM error!
-			undef $siglvl;
-		}
+		my($r, $sl, $mirs) = @{$db}{'name', 'siglvl', 'mirrors'};
+		next if(!@$mirs);
 
-		my $db = $alpm->register($name, $siglvl || 'default');
-		if(!$db){
-			die "Failed to register $name database: " . $alpm->strerror;
-		}
-		for my $url (@$mirs){
-			$db->add_server($url);
-		}
+		_expurls($mirs, $opts->{'arch'}, $r);
+		$sl = 'default' if(!$usesl);
+		my $x = $alpm->register($r, $sl)
+			or die "Failed to register $r database: " . $alpm->strerror;
+		$x->add_server($_) for(@$mirs);
 	}
 	return $alpm;
 }
@@ -276,8 +280,6 @@ sub parse
 {
 	my($self) = @_;
 
-	chomp ($ARCH = `uname -m`); # used by _addmirror
-
 	my (%opts, @dbs, $currsect, $defsiglvl);
 	my %fldhooks = (
 		_confhooks(\%opts, \$currsect),
